pub struct Health {
current: u32,
base_max: u32,
maximum: u32,
pub last_change: HealthChange,
pub is_dead: bool,
pub can_have_death_protection: bool,
pub death_protection: bool,
damage_contributors: HashMap<DamageContributor, (u64, Time)>,
}Expand description
Health is represented by u32s within the module, but treated as a float by the rest of the game.
Fields
current: u32Current health is how much health the entity currently has. Current health must be lower than or equal to maximum health.
base_max: u32Base max is the amount of health the entity has without considering temporary modifiers such as buffs
maximum: u32Maximum is the amount of health the entity has after temporary modifiers are considered
last_change: HealthChangeThe last change to health
is_dead: boolcan_have_death_protection: boolIf this entity supports having death protection.
death_protection: boolIf death protection is true, any damage that would kill instead leaves the entity at 1 health.
damage_contributors: HashMap<DamageContributor, (u64, Time)>Keeps track of damage per DamageContributor and the last time they caused damage, used for EXP sharing
Implementations
Sourceimpl Health
impl Health
Sourcepub const HEALTH_EPSILON: f32
pub const HEALTH_EPSILON: f32
Used when comparisons to health are needed outside this module.
Sourceconst MAX_HEALTH: u16
const MAX_HEALTH: u16
Maximum value allowed for health before scaling
Sourceconst MAX_SCALED_HEALTH: u32
const MAX_SCALED_HEALTH: u32
The maximum value allowed for current and maximum health Maximum value is (u16:MAX - 1) * 256, which only requires 24 bits. This can fit into an f32 with no loss to precision
Sourceconst SCALING_FACTOR_FLOAT: f32 = 256.
const SCALING_FACTOR_FLOAT: f32 = 256.
The amount health is scaled by within this module
const SCALING_FACTOR_INT: u32
Sourcepub fn set_fraction(&mut self, fraction: f32)
pub fn set_fraction(&mut self, fraction: f32)
Instantly set the health fraction.
pub fn set_amount(&mut self, amount: f32)
Sourcepub fn needs_maximum_update(&self, modifiers: StatsModifier) -> Option<u32>
pub fn needs_maximum_update(&self, modifiers: StatsModifier) -> Option<u32>
Calculates a new maximum value and returns it if the value differs from the current maximum.
Note: The returned value uses an internal format so don’t expect it to
be useful for anything other than a parameter to
Self::update_internal_integer_maximum.
Sourcepub fn update_internal_integer_maximum(&mut self, maximum: u32)
pub fn update_internal_integer_maximum(&mut self, maximum: u32)
Updates the maximum value for health.
Note: The accepted u32 value is in the internal format of this type.
So attempting to pass values that weren’t returned from
Self::needs_maximum_update can produce strange or unexpected
results.
pub fn new(body: Body) -> Self
Sourcepub fn change_by(&mut self, change: HealthChange) -> bool
pub fn change_by(&mut self, change: HealthChange) -> bool
Returns a boolean if the delta was not zero.
pub fn damage_contributions( &self, ) -> impl Iterator<Item = (&DamageContributor, &u64)>
pub fn recent_damagers(&self) -> impl Iterator<Item = (Uid, Time)> + '_
pub fn should_die(&self) -> bool
pub fn kill(&mut self)
pub fn revive(&mut self)
pub fn consume_death_protection(&mut self)
pub fn refresh_death_protection(&mut self)
pub fn has_consumed_death_protection(&self) -> bool